==> ultra-erp-clean-v2.1.zip: src/Views/catalog/suppliers/index.php <==
<h5>Yetkazib beruvchilar</h5>
<div class="mb-2 d-flex gap-2">
  <button class="btn btn-primary btn-sm" data-bs-toggle="modal" data-bs-target="#sNew"><i class="bi bi-plus"></i> Yangi</button>
</div>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Nomi</th><th>Tel</th><th>Region</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr>
  <td><?=$r['code']?></td><td><img src="<?=$r['avatar_url']?:('https://api.dicebear.com/7.x/initials/svg?seed='.urlencode($r['name']))?>" width="24" height="24" class="me-1"><?=$r['name']?></td>
  <td><?=$r['phone']?></td><td><?=$r['region']?></td>
  <td class="text-end">
    <button class="btn btn-outline-secondary btn-sm"
      data-bs-toggle="modal" data-bs-target="#sEdit"
      data-id="<?=$r['id']?>" data-code="<?=$r['code']?>" data-name="<?=$r['name']?>" data-phone="<?=$r['phone']?>" data-email="<?=$r['email']?>" data-region="<?=$r['region']?>" data-avatar="<?=$r['avatar_url']?>">Tahrirlash</button>
    <form method="post" action="?r=catalog/suppliers/delete" onsubmit="return confirm('O‘chirish?')" class="d-inline">
      <input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button>
    </form>
  </td>
</tr><?php endforeach; ?></tbody></table>

<!-- New -->
<div class="modal fade" id="sNew" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Yangi yetkazib beruvchi</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=catalog/suppliers/create"><div class="modal-body"><div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" required></div>
  <div class="col-md-4"><label class="form-label">Telefon</label><input class="form-control form-control-sm" name="phone"></div>
  <div class="col-md-4"><label class="form-label">Email</label><input class="form-control form-control-sm" name="email"></div>
  <div class="col-md-4"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" placeholder="https://..."></div>
  <div class="col-md-4"><label class="form-label">Region</label><input class="form-control form-control-sm" name="region"></div>
</div></div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>

<!-- Edit -->
<div class="modal fade" id="sEdit" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Tahrirlash</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=catalog/suppliers/update"><div class="modal-body">
<input type="hidden" name="id" id="se_id">
<div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" id="se_code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" id="se_name" required></div>
  <div class="col-md-4"><label class="form-label">Telefon</label><input class="form-control form-control-sm" name="phone" id="se_phone"></div>
  <div class="col-md-4"><label class="form-label">Email</label><input class="form-control form-control-sm" name="email" id="se_email"></div>
  <div class="col-md-4"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" id="se_avatar"></div>
  <div class="col-md-4"><label class="form-label">Region</label><input class="form-control form-control-sm" name="region" id="se_region"></div>
</div>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
<script>
document.getElementById('sEdit').addEventListener('show.bs.modal', function (ev){
  const b = ev.relatedTarget;
  se_id.value=b.dataset.id; se_code.value=b.dataset.code; se_name.value=b.dataset.name;
  se_phone.value=b.dataset.phone; se_email.value=b.dataset.email; se_region.value=b.dataset.region; se_avatar.value=b.dataset.avatar;
});
</script>

==> ultra-erp-clean-v2.2.zip: src/Views/catalog/suppliers/index.php <==
<h5>Yetkazib beruvchilar</h5>
<button class="btn btn-primary btn-sm mb-2" data-bs-toggle="modal" data-bs-target="#sNew"><i class="bi bi-plus"></i> Yangi</button>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Nomi</th><th>Tel</th><th>Region</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr>
  <td><?=$r['code']?></td><td><img src="<?=$r['avatar_url']?:('https://api.dicebear.com/7.x/initials/svg?seed='.urlencode($r['name']))?>" width="24" height="24" class="me-1"><?=$r['name']?></td>
  <td><?=$r['phone']?></td><td><?=$r['region']?></td>
  <td class="text-end"><form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>" onsubmit="return confirm('O‘chirish?')" class="d-inline"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form></td>
</tr><?php endforeach; ?></tbody></table>
<div class="modal fade" id="sNew" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Yangi yetkazib beruvchi</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>"><div class="modal-body"><div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" required></div>
  <div class="col-md-4"><label class="form-label">Telefon</label><input class="form-control form-control-sm" name="phone"></div>
  <div class="col-md-4"><label class="form-label">Email</label><input class="form-control form-control-sm" name="email"></div>
  <div class="col-md-4"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" placeholder="https://..."></div>
  <div class="col-md-4"><label class="form-label">Region</label><input class="form-control form-control-sm" name="region"></div>
</div></div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
